library(testthat)
library(gsDesign2)

test_check("gsDesign2")
